@@ -17,16 +17,16 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h,v 1.73 2002/07/18 14:29:45 beerli Exp $
+$Id: definitions.h,v 1.75 2002/08/13 16:33:25 beerli Exp $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.6.7"
+#define MIGRATEVERSION "1.6.8"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "1.6.7"
+#define MIGRATEVERSION "1.6.8"
 #endif
 #endif
 
@@ -43,7 +43,11 @@ $Id: definitions.h,v 1.73 2002/07/18 14:29:45 beerli Exp $
 #endif
 
 #define FGETS  myfgets
-
+#ifdef MPI
+#define FPRINTF mpi_fprintf
+#else
+#define FPRINTF fprintf
+#endif
 #ifdef __MWERKS__
 #include "conf.h"
 #undef HAVE_LGAMMA
@@ -65,26 +69,47 @@ $Id: definitions.h,v 1.73 2002/07/18 14:29:45 beerli Exp $
 #ifndef HAVE_STRFTIME
 #define NOTIME_FUNC
 #endif
+#define STDOUTNUM 0
 #define INFILE "infile"
+#define INFILENUM 1
 #define WEIGHTFILE "weightfile"
+#define WEIGHTFILENUM 2
 #define CATFILE "catfile"
+#define CATFILENUM 3
 #define SEEDFILE "seedfile"
+#define SEEDFILENUM 4
 #define PARMFILE "parmfile"
+#define PARMFILENUM 5
 #define OUTFILE "outfile"
+#define OUTFILENUM 6
 #define LOGFILE "logfile"
+#define LOGFILENUM 7
 #define TREEFILE "treefile"
+#define TREEFILENUM 8
 #define UTREEFILE "usertree"
+#define UTREEFILENUM 9
 #define INTREE "intree"
+#define INTREENUM 10
 #define OUTTREE "outtree"
+#define OUTTREENUM 11
 #define MATHFILE "mathfile"
+#define MATHFILENUM 12
 #define SUMFILE "sumfile"
+#define SUMFILENUM 13
 #define MIGHISTFILE "mighistfile"
+#define MIGHISTFILENUM 14
 #define DISTFILE "distfile"
+#define DISTFILENUM 15
 #define GEOFILE "geofile"
+#define GEOFILENUM 16
 #define BOOTFILE "bootstrapfile"
+#define BOOTFILENUM 17
 #define UEPFILE "uepfile"
+#define UEPFILENUM 18
 #define AICFILE "aicfile"
+#define AICFILENUM 19
 #define BAYESFILE "bayesfile"
+#define BAYESFILENUM 20
 #ifdef __STDIO_LOADED
 #define VMS
 #define MACHINE_TYPE "VAX/VMS C"
