@@ -15,7 +15,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: lrt.c,v 1.19 2002/07/18 14:29:45 beerli Exp $
+$Id: lrt.c,v 1.20 2002/08/12 21:13:53 beerli Exp $
  
 -------------------------------------------------------*/
 #define SICK_VALUE    -1
@@ -86,7 +86,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
 
 
     if (world->options->progress)
-        fprintf (stdout, "           Printing likelihood ratio tests\n");
+        FPRINTF (stdout, "           Printing likelihood ratio tests\n");
 
     nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
     create_nr (nr, world, *Gmax, 0, world->loci, world->repkind, world->rep);
@@ -137,7 +137,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
                             world->options->lratio->data[c].value1,
                             world->options->lratio->data[c].value2);
         }
-        //      fprintf (world->outfile, "Remember: Tests based on a single locus may not be valid\n");
+        //      FPRINTF (world->outfile, "Remember: Tests based on a single locus may not be valid\n");
     }
     fflush (world->outfile);
     free (param0);
@@ -287,29 +287,29 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df,
 
     if (withhead)
     {
-        fprintf (world->outfile,
+        FPRINTF (world->outfile,
                  "==============================================================================\n");
-        fprintf (world->outfile, "Likelihood ratio tests\n");
-        fprintf (world->outfile,
+        FPRINTF (world->outfile, "Likelihood ratio tests\n");
+        FPRINTF (world->outfile,
                  "==============================================================================\n");
-        fprintf (world->outfile, "Over all loci\n");
-        fprintf (world->outfile,
+        FPRINTF (world->outfile, "Over all loci\n");
+        FPRINTF (world->outfile,
                  "[Theta values are on the diagonal of the Migration matrix,\nmigration rates are specified as Theta*M]\n");
         part1len = MAX (part1len, part2len - part1len);
-        fprintf (world->outfile,
+        FPRINTF (world->outfile,
                  "%*.*s           %-10.10s   %-3.3s   %-4.4s %-5.5s\n",
                  (int) part1len, (int) part1len, " ", "Test value", "Df",
                  "Prob", "Prob*");
         for (i = 0; i < part1len + 35; i++)
             fputc ('-', world->outfile);
-        fprintf (world->outfile, "\n");
+        FPRINTF (world->outfile, "\n");
     }
     if (testval > 10000 && chiprob < EPSILON)
         sprintf (temp, ">10000.00");
     else
         sprintf (temp, "%10.2f", testval);
-    fprintf (world->outfile, "You entered\n[%s]\n", this_string);
-    fprintf (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n",
+    FPRINTF (world->outfile, "You entered\n[%s]\n", this_string);
+    FPRINTF (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n",
              teststat, spacer, like0, like1, temp, df, chiprob, message);
     free (teststat);
     free (lparam0);
@@ -451,31 +451,31 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df,
 
     if (withhead)
     {
-        fprintf (world->outfile,
+        FPRINTF (world->outfile,
                  "==============================================================================\n");
-        fprintf (world->outfile, "Likelihood ratio tests\n");
-        fprintf (world->outfile,
+        FPRINTF (world->outfile, "Likelihood ratio tests\n");
+        FPRINTF (world->outfile,
                  "==============================================================================\n");
-        fprintf (world->outfile, "Over all loci\n");
-        fprintf (world->outfile,
+        FPRINTF (world->outfile, "Over all loci\n");
+        FPRINTF (world->outfile,
                  "[Theta values are on the diagonal of the Migration matrix,\nmigration rates are specified as Theta*M]\n");
         part1len = MAX (part1len, part2len - part1len);
-        fprintf (world->outfile,
+        FPRINTF (world->outfile,
                  "%*.*s      %-10.10s   %-3.3s   %-4.4s %-5.5s\n",
                  (int) part1len, (int) part1len, " ", "Test value", "Df",
                  "Prob", "Prob*");
         for (i = 0; i < part1len + 35; i++)
             fputc ('-', world->outfile);
-        fprintf (world->outfile, "\n");
+        FPRINTF (world->outfile, "\n");
     }
 
     if (testval > 10000 && chiprob < EPSILON)
         sprintf (temp, ">10000.00");
     else
         sprintf (temp, "%10.2f", testval);
-    fprintf (world->outfile, "You entered\n[%s]\n", this_string1);
-    //fprintf (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n", teststat, spacer, like0, like1, temp, df, chiprob, message);
-    fprintf (world->outfile, "%s\n", teststat);
+    FPRINTF (world->outfile, "You entered\n[%s]\n", this_string1);
+    //FPRINTF (world->outfile, "%s %s -2(%6.3f-%6.3f)=%11.11s %3li %8.5f %s\n", teststat, spacer, like0, like1, temp, df, chiprob, message);
+    FPRINTF (world->outfile, "%s\n", teststat);
     free (teststat);
     free (lparam0);
     free (lparam1);
