@@ -15,7 +15,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: menu.c,v 1.57 2002/07/18 14:29:45 beerli Exp $
+$Id: menu.c,v 1.58 2002/08/12 21:13:54 beerli Exp $
  
 -------------------------------------------------------*/
 #include "migration.h"
@@ -29,7 +29,7 @@ $Id: menu.c,v 1.57 2002/07/18 14:29:45 beerli Exp $
 #endif
 /* prototypes ------------------------------------------- */
 void print_menu_title (FILE * file, option_fmt * options);
-void print_menu_accratio (FILE * file, long a, long b);
+void print_menu_accratio (long a, long b, world_fmt *world);
 long print_title (world_fmt * world, option_fmt * options);
 void get_menu (option_fmt * options);
 /* private functions */
@@ -77,33 +77,76 @@ print_menu_title (FILE * file, option_fmt * options)
     char nowstr[LINESIZE];
     if (options->menu || options->progress)
     {
-        fprintf (file, "  =============================================\n");
-        fprintf (file, "  MIGRATION RATE AND POPULATION SIZE ESTIMATION\n");
-        fprintf (file, "  using Markov Chain Monte Carlo simulation\n");
-        fprintf (file, "  =============================================\n");
+        FPRINTF (file, "  =============================================\n");
+        FPRINTF (file, "  MIGRATION RATE AND POPULATION SIZE ESTIMATION\n");
+        FPRINTF (file, "  using Markov Chain Monte Carlo simulation\n");
+        FPRINTF (file, "  =============================================\n");
 #ifdef MPI
 
-        fprintf (file, "  compiled for a PARALLEL COMPUTER ARCHITECTURE\n");
+        FPRINTF (file, "  compiled for a PARALLEL COMPUTER ARCHITECTURE\n");
 #endif
 #ifdef ALTIVEC
 
-        fprintf (file, "  compiled for a ALTIVEC\n");
+        FPRINTF (file, "  compiled for a ALTIVEC\n");
 #endif
 
-        fprintf (file, "  Version %s\n", MIGRATEVERSION);
+        FPRINTF (file, "  Version %s\n", MIGRATEVERSION);
         get_time (nowstr, "  %c");
         if (nowstr[0] != '\0')
-            fprintf (file, "  Program started at %s\n", nowstr);
-        fprintf (file, "\n\n");
+            FPRINTF (file, "  Program started at %s\n", nowstr);
+        FPRINTF (file, "\n\n");
     }
 }
 
 void
-print_menu_accratio (FILE * file, long a, long b)
+print_menu_accratio (long a, long b, world_fmt *world)
 {
-
-    fprintf (file, "           Acceptance-ratio = %li/%li (%f)\n\n", a, b,
+	// printing machinery
+	char *buffer;
+	long bufsize=0;
+#ifdef MPI
+	char *finalbuffer;
+	long filehandle1 = 0;
+	long filehandle2 = 0;
+#endif
+	boolean writelog = world->options->writelog;
+	boolean progress = world->options->progress;
+	//
+	if(writelog || progress)
+	  {
+		buffer = (char *) calloc(MAXBUFSIZE,sizeof(char));
+#ifdef MPI
+		finalbuffer = (char *) calloc(MAXBUFSIZE,sizeof(char));
+#endif
+		
+    	bufsize += sprintf(buffer+bufsize, "           Acceptance-ratio = %li/%li (%f)\n\n", a, b,
              (double) a / (double) b);
+
+	if (progress)
+	  {
+#ifdef MPI
+		filehandle1 = get_filehandle2(stdout, world);
+		bufsize = sprintf(finalbuffer,"%c%li:%s",'M',filehandle1,buffer);
+		MPI_Send (finalbuffer, bufsize, MPI_CHAR, MASTER, myID, comm_world);
+#else
+		FPRINTF(stdout,"%s",buffer);
+#endif
+	  }
+	if(writelog)
+	  {
+#ifdef MPI
+		filehandle2 = get_filehandle2(world->options->logfile, world);
+		bufsize = sprintf(finalbuffer,"%c%li:%s",'M',filehandle2,buffer);
+		MPI_Send (finalbuffer, bufsize, MPI_CHAR, MASTER, myID, comm_world);
+#else
+		FPRINTF(world->options->logfile,"%s",buffer);
+#endif
+	  }
+	free(buffer);
+#ifdef MPI
+	free(finalbuffer);
+#endif
+	  }
 }
 
 long
@@ -113,37 +156,37 @@ print_title (world_fmt * world, option_fmt * options)
     long len = 45, i, filepos = -1;
     if (!world->options->simulation)
     {
-        fprintf (world->outfile, "  ");
+        FPRINTF (world->outfile, "  ");
         if (options->title[0] != '\0')
         {
             len = (long) MAX (strlen (options->title), 45);
             for (i = 0; i < len; i++)
-                fprintf (world->outfile, "=");
-            fprintf (world->outfile, "\n  %s\n  ", options->title);
+                FPRINTF (world->outfile, "=");
+            FPRINTF (world->outfile, "\n  %s\n  ", options->title);
         }
         for (i = 0; i < len; i++)
-            fprintf (world->outfile, "=");
+            FPRINTF (world->outfile, "=");
 
-        fprintf (world->outfile,
+        FPRINTF (world->outfile,
                  "\n  MIGRATION RATE AND POPULATION SIZE ESTIMATION\n");
-        fprintf (world->outfile,
+        FPRINTF (world->outfile,
                  "  using Markov Chain Monte Carlo simulation\n  ");
 
         for (i = 0; i < len; i++)
-            fprintf (world->outfile, "=");
-        fprintf (world->outfile, "\n  Version %s\n", MIGRATEVERSION);
+            FPRINTF (world->outfile, "=");
+        FPRINTF (world->outfile, "\n  Version %s\n", MIGRATEVERSION);
         get_time (nowstr, "%c");
         if (nowstr[0] != '\0')
         {
-            fprintf (world->outfile, "\n  Program started at %s\n", nowstr);
+            FPRINTF (world->outfile, "\n  Program started at %s\n", nowstr);
             filepos = ftell (world->outfile);
             /* DO NOT REMOVE the blanks in the following print statement,
                they are overwritten at the program end with the timestamp
              */
-            fprintf (world->outfile,
+            FPRINTF (world->outfile,
                      "                                                   \n");
         }
-        fprintf (world->outfile, "\n\n");
+        FPRINTF (world->outfile, "\n\n");
     }
     return filepos;
 }
@@ -493,14 +536,14 @@ menuData (option_fmt * options, char datatype[])
                     //  for (z = 0; z < options->rcategs; z++)
                     //    options->probcat[z] = 1. / options->rcategs;
 
-                    fprintf (stdout,
+                    FPRINTF (stdout,
                              "\n\nRegion type     Rate of change    Probability\n");
-                    fprintf (stdout,
+                    FPRINTF (stdout,
                              "---------------------------------------------\n");
                     for (i = 0; i < options->rcategs; i++)
-                        fprintf (stdout, "%9ld%16.3f%17.3f\n",
+                        FPRINTF (stdout, "%9ld%16.3f%17.3f\n",
                                  i + 1, options->rrate[i], options->probcat[i]);
-                    fprintf (stdout, "\n");
+                    FPRINTF (stdout, "\n");
 
 
                 }
@@ -517,7 +560,7 @@ menuData (option_fmt * options, char datatype[])
                 options->interleaved = !options->interleaved;
                 break;
             case 9:
-                fprintf (stdout,
+                FPRINTF (stdout,
                          "Enter the sequencing error rate per site\n[Good values are 0.0 (=no error), or 0.01 (1%% error):\n");
                 FGETS (input, LINESIZE, stdin);
                 options->seqerror = atof (input);
@@ -1027,8 +1070,8 @@ menuInput (option_fmt * options)
             set_profile_options (options);
             break;
         case MI_LRT:
-            fprintf (stdout, "  Likelihood-Ratio tests:\n");
-            fprintf (stdout, "  -----------------------\n");
+            FPRINTF (stdout, "  Likelihood-Ratio tests:\n");
+            FPRINTF (stdout, "  -----------------------\n");
             read_custom_menu_lratio (options);
             break;
         case MI_AIC:
@@ -1164,10 +1207,10 @@ menuInput (option_fmt * options)
         case MI_UEPRATE:
             do
             {
-                fprintf (stdout, "What is mutation rate for the UEP locus\n");
-                fprintf (stdout,
+                FPRINTF (stdout, "What is mutation rate for the UEP locus\n");
+                FPRINTF (stdout,
                          "[expressed as a ratio of the point mutation rate\n");
-                fprintf (stdout, "Reasonable values are 0.0 =< x <=1.0]\n");
+                FPRINTF (stdout, "Reasonable values are 0.0 =< x <=1.0]\n");
                 FGETS (input, LINESIZE, stdin);
                 options->ueprate = atof (input);
             }
@@ -1176,8 +1219,8 @@ menuInput (option_fmt * options)
         case MI_UEPFREQ:
             do
             {
-                fprintf (stdout, "What is the base frequency for the \"1\" allele\n");
-                fprintf (stdout, "Reasonable values are 0.0 < x <1.0]\n");
+                FPRINTF (stdout, "What is the base frequency for the \"1\" allele\n");
+                FPRINTF (stdout, "Reasonable values are 0.0 < x <1.0]\n");
                 FGETS (input, LINESIZE, stdin);
                 options->uepfreq1 = atof (input);
                 options->uepfreq0 = 1. - options->uepfreq1;
@@ -1738,13 +1781,13 @@ void menuHeat(option_fmt *options, char *input)
 {
     if (options->heating > 0)
     {
-        fprintf (stdout,
+        FPRINTF (stdout,
                  "Enter the number of different \"heated\" chains.\nMinimum is 4\n");
         FGETS (input, LINESIZE, stdin);
         options->heated_chains = atol (input);
         if (options->heated_chains < 4)
             options->heated_chains = HEATED_CHAIN_NUM;
-        fprintf (stdout,
+        FPRINTF (stdout,
                  "Enter the interval between swapping trees\n[Current interval is %li]\n",
                  options->heating_interval);
         FGETS (input, LINESIZE, stdin);
@@ -2141,14 +2184,14 @@ read_heatvalues (option_fmt * options)
     char *tmp;
     char input[LINESIZE];
     double diff = 0.;
-    fprintf (stdout, " ");
-    fprintf (stdout, "Enter %li \"temperatures\".\n", options->heated_chains);
-    fprintf (stdout,
+    FPRINTF (stdout, " ");
+    FPRINTF (stdout, "Enter %li \"temperatures\".\n", options->heated_chains);
+    FPRINTF (stdout,
              "or give a range of values [linear increase:      1 - 10]\n");
-    fprintf (stdout,
+    FPRINTF (stdout,
              "or give a range of values [exponential increase: 1 @ 10]\n");
-    fprintf (stdout, "The coldest, which is the first, has to be 1\n");
-    fprintf (stdout, "[For example: 1 1.5 3 6]\n");
+    FPRINTF (stdout, "The coldest, which is the first, has to be 1\n");
+    FPRINTF (stdout, "[For example: 1 1.5 3 6]\n");
     FGETS (input, LINESIZE, stdin);
     if (strstr (input, "-"))
     {
@@ -2194,7 +2237,7 @@ read_heatvalues (option_fmt * options)
                 {
                     if (z < options->heated_chains)
                     {
-                        fprintf (stdout, "%li more values are needed\n",
+                        FPRINTF (stdout, "%li more values are needed\n",
                                  options->heated_chains - z);
                         FGETS (input, LINESIZE, stdin);
                         tmp = strtok (input, " ,");
@@ -2209,11 +2252,11 @@ read_heatvalues (option_fmt * options)
             }
         }
     }
-    fprintf (stdout, "Chain         Temperature\n");
-    fprintf (stdout, "-------------------------\n");
+    FPRINTF (stdout, "Chain         Temperature\n");
+    FPRINTF (stdout, "-------------------------\n");
     for (i = options->heated_chains - 1; i >= 0; --i)
-        fprintf (stdout, "%4li             %f\n", i, options->heat[i]);
-    fprintf (stdout, "\n\nIs this correct? [Yes or No]\n");
+        FPRINTF (stdout, "%4li             %f\n", i, options->heat[i]);
+    FPRINTF (stdout, "\n\nIs this correct? [Yes or No]\n");
     FGETS (input, LINESIZE, stdin);
     if ('y' != tolower (input[0]))
         read_heatvalues (options);
