@@ -10,7 +10,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-  $Id: mig-histogram.c,v 1.4 2002/06/20 06:25:36 beerli Exp $
+  $Id: mig-histogram.c,v 1.5 2002/08/12 21:13:54 beerli Exp $
  
  */
 
@@ -53,7 +53,7 @@ print_mighist_file (FILE * mighist, world_fmt * world)
             //copies = aa->mighist[j].copies;
             for (i = 0; i < aa->mighist[j].migeventsize; i++)
             {
-                fprintf (mighist, "%f %f %f\n",
+                FPRINTF (mighist, "%f %f %f\n",
                          aa->mighist[j].migevents[i][0],
                          aa->mighist[j].migevents[i][1],
                          aa->mighist[j].migevents[i][2]);
@@ -94,35 +94,35 @@ print_mighist_output (FILE * out, world_fmt * world, double ***migtable,
 {
     long loc, p1;
     long loci1 = world->loci == 1 ? 1 : world->loci + 1;
-    fprintf (out, "\n\nSummary of Migration Events\n");
-    fprintf (out, "===============================\n\n");
+    FPRINTF (out, "\n\nSummary of Migration Events\n");
+    FPRINTF (out, "===============================\n\n");
     for (loc = 0; loc < world->loci; loc++)
         total[world->loci] += total[loc];
     for (loc = 0; loc < loci1; loc++)
     {    /* Each locus + Summary */
         if (loc != world->loci)
-            fprintf (out, "Locus %li\n", loc + 1);
+            FPRINTF (out, "Locus %li\n", loc + 1);
         else
-            fprintf (out, "Over all loci\n");
-        fprintf (out,
+            FPRINTF (out, "Over all loci\n");
+        FPRINTF (out,
                  "---------------------------------------------------------\n");
-        fprintf (out,
+        FPRINTF (out,
                  "Population   Time                             Frequency\n");
-        fprintf (out, "             -----------------------------\n");
-        fprintf (out, "From    To   Average    Median     SE\n");
-        fprintf (out,
+        FPRINTF (out, "             -----------------------------\n");
+        FPRINTF (out, "From    To   Average    Median     SE\n");
+        FPRINTF (out,
                  "---------------------------------------------------------\n");
         for (p1 = 0; p1 < world->numpop2; p1++)
         {
             if (migtable[loc][p1][0] != migtable[loc][p1][1])
             {
                 if (migtable[loc][p1][2] == NOAVERAGE)
-                    fprintf (out, "%4li %4li    No migration event encountered\n",
+                    FPRINTF (out, "%4li %4li    No migration event encountered\n",
                              (long) migtable[loc][p1][0] + 1,
                              (long) migtable[loc][p1][1] + 1);
                 else
                 {
-                    fprintf (out,
+                    FPRINTF (out,
                              "%4li %4li    %3.5f    %3.5f    %3.5f    %3.5f\n",
                              (long) migtable[loc][p1][0] + 1,
                              (long) migtable[loc][p1][1] + 1,
@@ -132,9 +132,9 @@ print_mighist_output (FILE * out, world_fmt * world, double ***migtable,
                 }
             }
         }
-        fprintf (out,
+        FPRINTF (out,
                  "---------------------------------------------------------\n");
-        fprintf (out, "\n");
+        FPRINTF (out, "\n");
     }
 }
 
@@ -617,15 +617,15 @@ print_histogram_ascii (FILE * out, histogram_fmt ** histogram,
         if (loc == (loci - 1))
         {
             if (loci > 1)
-                fprintf (out,
+                FPRINTF (out,
                          "\nOver all loci\n------------------------------------------------------------------\n");
             else
-                fprintf (out,
+                FPRINTF (out,
                          "\nLocus %li\n------------------------------------------------------------------\n",
                          loc + 1);
         }
         else
-            fprintf (out,
+            FPRINTF (out,
                      "\nLocus %li\n------------------------------------------------------------------\n",
                      loc + 1);
 
@@ -633,23 +633,23 @@ print_histogram_ascii (FILE * out, histogram_fmt ** histogram,
         {
             if (plotfield[loc][i].print)
             {
-                fprintf (out, "%s\n\n%10.10s %10.10s %10.10s\n",
+                FPRINTF (out, "%s\n\n%10.10s %10.10s %10.10s\n",
                          plotfield[loc][i].title, plotfield[loc][i].xaxis,
                          plotfield[loc][i].yaxis, plotfield[loc][i].yfaxis);
                 for (j = 0; j < bins; j++)
                 {
-                    fprintf (stdout,
+                    FPRINTF (stdout,
                              "loc=%li i=%li j=%li %10.6f %10li %10.6f %s\n",
                              loc, i, j, binning[j], plotfield[loc][i].y[j],
                              plotfield[loc][i].yfreq[j],
                              plotfield[loc][i].data[j]);
 
-                    fprintf (out,
+                    FPRINTF (out,
                              "%10.6f %10li %10.6f %s\n", binning[j],
                              plotfield[loc][i].y[j], plotfield[loc][i].yfreq[j],
                              plotfield[loc][i].data[j]);
                 }
-                fprintf (out, " \n");
+                FPRINTF (out, " \n");
             }
         }
     }
