@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c,v 1.41 2002/06/20 06:25:38 beerli Exp $
+ $Id: sequence.c,v 1.43 2002/08/12 22:09:49 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -1126,30 +1126,41 @@ inputweights (world_fmt * world, data_fmt * data, long chars)
     /* input the character weights, 0-9 and A-Z for weights 0 - 35 */
     char ch;
     long i;
-
-    for (i = 0; i < chars; i++)
+    ch = getc (data->weightfile);
+    while (ch == '#')
     {
-        do
-        {
+        while (ch != '\n')
             ch = getc (data->weightfile);
-            if (ch == '\n')
-                ch = ' ';
-        }
-        while (ch == ' ');
-        world->data->seq->weight[i] = 1;
-        if (isdigit ((int) ch))
-            world->data->seq->weight[i] = ch - '0';
-        else if (isalpha ((int) ch))
-        {
-            ch = uppercase (ch);
-            world->data->seq->weight[i] = (short) (ch - 'A' + 10);
-        }
-        else
-        {
-            printf ("BAD WEIGHT CHARACTER: %c\n", ch);
-            exit (EXIT_FAILURE);
-        }
+        ch = getc (data->weightfile);
     }
+    ungetc (ch, data->weightfile);
+    for(i=0;i<chars;i++)
+      {
+	world->data->seq->weight[i] = 1;
+        ch = getc (data->weightfile);
+	
+	if (isdigit ((int) ch))
+	  world->data->seq->weight[i] = ch - '0';
+	else 
+	  {
+	    if (isalpha ((int) ch))
+	      {
+		ch = uppercase (ch);
+		world->data->seq->weight[i] = (short) (ch - 'A' + 10);
+	      }
+	    else
+	      {
+		if(isspace((int) ch))
+		  {
+		    i--;
+		    continue;
+		  }
+		else
+		  printf ("ERROR: Bad weight character: %c\n", ch);
+		exit (EXIT_FAILURE);
+	      }
+	  }
+      }
 }    /* inputweights */
 
 void
@@ -1333,27 +1344,27 @@ print_tbl (FILE * outfile, world_fmt * world, option_fmt * options,
     opt = options;
     if (opt->rcategs > 1)
     {
-        fprintf (outfile, "\nRegion type     Rate of change    Probability\n");
-        fprintf (outfile, "---------------------------------------------\n");
+        FPRINTF (outfile, "\nRegion type     Rate of change    Probability\n");
+        FPRINTF (outfile, "---------------------------------------------\n");
         for (i = 0; i < opt->rcategs; i++)
-            fprintf (outfile, "%9ld%16.3f%17.3f\n", i + 1, opt->rrate[i],
+            FPRINTF (outfile, "%9ld%16.3f%17.3f\n", i + 1, opt->rrate[i],
                      opt->probcat[i]);
         putc ('\n', outfile);
         if (opt->autocorr)
-            fprintf (outfile,
+            FPRINTF (outfile,
                      "Expected length of a patch of sites having the same rate = %8.3f\n",
                      1. / opt->lambda);
         putc ('\n', outfile);
     }
     if (opt->categs > 1)
     {
-        fprintf (outfile, "Site category   Rate of change\n");
-        fprintf (outfile, "------------------------------\n");
+        FPRINTF (outfile, "Site category   Rate of change\n");
+        FPRINTF (outfile, "------------------------------\n");
         for (i = 0; i < opt->categs; i++)
-            fprintf (outfile, "%9ld%16.3f\n", i + 1, opt->rate[i]);
+            FPRINTF (outfile, "%9ld%16.3f\n", i + 1, opt->rate[i]);
     }
     if ((opt->rcategs > 1) || (opt->categs > 1))
-        fprintf (outfile, "\n");
+        FPRINTF (outfile, "\n");
 }
 
 
@@ -1363,7 +1374,7 @@ printweights (FILE * outfile, world_fmt * world, option_fmt * options,
 {
     /* print out the weights of sites */
     long i, j;
-    fprintf (outfile, "\n    %s are weighted as follows:\n", letters);
+    FPRINTF (outfile, "\n    %s are weighted as follows:\n", letters);
     for (i = 0; i < chars; i++)
     {
         if (i % 60 == 0)
@@ -1372,11 +1383,11 @@ printweights (FILE * outfile, world_fmt * world, option_fmt * options,
             for (j = 1; j <= options->nmlength + 3; j++)
                 putc (' ', outfile);
         }
-        fprintf (outfile, "%hd", weight[i + inc]);
+        FPRINTF (outfile, "%hd", weight[i + inc]);
         if ((i + 1) % 10 == 0 && (i + 1) % 60 != 0)
             putc (' ', outfile);
     }
-    fprintf (outfile, "\n\n");
+    FPRINTF (outfile, "\n\n");
 }    /* printweights */
 
 
@@ -1387,23 +1398,23 @@ print_seqfreqs (FILE * outfile, world_fmt * world, option_fmt * options)
     if (world->locus == 0 || outfile == stdout)
     {
         if (options->freqsfrom)
-            fprintf (outfile, "\nEmpirical ");
-        fprintf (outfile, "Base Frequencies\n");
-        fprintf (outfile,
+            FPRINTF (outfile, "\nEmpirical ");
+        FPRINTF (outfile, "Base Frequencies\n");
+        FPRINTF (outfile,
                  "------------------------------------------------------------\n");
-        fprintf (outfile,
+        FPRINTF (outfile,
                  "Locus     Nucleotide                        Transition/\n");
-        fprintf (outfile,
+        FPRINTF (outfile,
                  "          ------------------------------  Transversion ratio\n");
-        fprintf (outfile, "          A       C       G       T(U)\n");
-        fprintf (outfile,
+        FPRINTF (outfile, "          A       C       G       T(U)\n");
+        FPRINTF (outfile,
                  "------------------------------------------------------------\n");
     }
-    fprintf (outfile, "%4li      %6.4f  %6.4f  %6.4f  %6.4f    %10.5f\n",
+    FPRINTF (outfile, "%4li      %6.4f  %6.4f  %6.4f  %6.4f    %10.5f\n",
              world->locus + 1, options->freqa, options->freqc, options->freqg,
              options->freqt, world->data->seq->ttratio);
     if (outfile == stdout)
-        fprintf (outfile, "\n");
+        FPRINTF (outfile, "\n");
 
 }
 
