@@ -22,7 +22,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c,v 1.17 2002/07/18 14:29:46 beerli Exp $                  
+   $Id: sighandler.c,v 1.18 2002/08/12 21:13:56 beerli Exp $                  
    ----------------------------------------------------- */
 //#include <stdio.h>
 #ifndef __MWERKS__
@@ -103,79 +103,79 @@ signalhandler (int sig)
     case SIGIOT:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "\nSEVERE ERROR: Input/Output problem!\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "\nSEVERE ERROR: Input/Output problem!\n");
+        FPRINTF (stderr,
                  "              Most likely a fatal error in the infile or parmfile\n\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Please report error with as much detail as possible to\n");
-        fprintf (stderr, "              %s\n\n", MAINTAINER);
+        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGTRAP:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "SEVERE ERROR: Trace trap\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "SEVERE ERROR: Trace trap\n");
+        FPRINTF (stderr,
                  "              there was an an overflow/underflow/0 divide problem\n");
-        fprintf (stderr, "              or some other problems.\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "              or some other problems.\n");
+        FPRINTF (stderr,
                  "              But check your infile for errors, too.\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Please report error with as much detail as possible to\n");
-        fprintf (stderr, "              %s\n\n", MAINTAINER);
+        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGBUS:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "SEVERE ERROR: Bus problems\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "SEVERE ERROR: Bus problems\n");
+        FPRINTF (stderr,
                  "              this results in an non recoverable crash\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              But check your infile for errors, too.\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Please report error with as much detail as possible to\n");
-        fprintf (stderr, "              %s\n\n", MAINTAINER);
+        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGXCPU:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "SEVERE ERROR: This program has a time limit?\n");
-        fprintf (stderr, "              We didn' program in a time limit,\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "SEVERE ERROR: This program has a time limit?\n");
+        FPRINTF (stderr, "              We didn' program in a time limit,\n");
+        FPRINTF (stderr,
                  "              report this error to your system administrator, please.\n");
         exit (sig);
         break;
     case SIGXFSZ:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "SEVERE ERROR: This program has a file size limit?\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "SEVERE ERROR: This program has a file size limit?\n");
+        FPRINTF (stderr,
                  "              We didn't program in a file size limit,\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              report this error to your system administrator, please.\n");
         exit (sig);
         break;
     case SIGUSR1:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a USER (?) SIGNAL\n", myID);
+        FPRINTF(stderr, "On node %i happened a USER (?) SIGNAL\n", myID);
         exit(sig);
 #endif
         //      warning ("\nUser signal received and ignored\n\n");
@@ -186,53 +186,53 @@ signalhandler (int sig)
     case SIGFPE:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "SEVERE ERROR: Floating point exception\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "SEVERE ERROR: Floating point exception\n");
+        FPRINTF (stderr,
                  "              There was an integer/floating point problem\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Often this is a division by zero. If you dataset is moderately sized\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              this is most likely an error in you data (infile).\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Please report error with as much detail as possible to\n");
-        fprintf (stderr, "              %s\n\n", MAINTAINER);
+        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGSEGV:
 #ifdef MPI
 
-        fprintf (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",
+        FPRINTF (stderr, "SEVERE ERROR: Segmentation fault on Node **%i**\n",
                  myID);
 #else
 
-        fprintf (stderr, "SEVERE ERROR: Segmentation fault\n");
+        FPRINTF (stderr, "SEVERE ERROR: Segmentation fault\n");
 #endif
 
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              this results in an non recoverable crash.\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              But check the datatype and your infile for errors, too.\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Please report error with as much detail as possible to\n");
-        fprintf (stderr, "              %s\n\n", MAINTAINER);
+        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     case SIGILL:
 #ifdef MPI
 
-        fprintf(stderr, "On node %i happened a", myID);
+        FPRINTF(stderr, "On node %i happened a", myID);
 #endif
 
-        fprintf (stderr, "SEVERE ERROR: Illegal instruction!\n");
-        fprintf (stderr, "              this is maybe a programming error.\n");
-        fprintf (stderr,
+        FPRINTF (stderr, "SEVERE ERROR: Illegal instruction!\n");
+        FPRINTF (stderr, "              this is maybe a programming error.\n");
+        FPRINTF (stderr,
                  "              But check your infile for errors, too.\n");
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "              Please report error with as much detail as possible to\n");
-        fprintf (stderr, "              %s\n\n", MAINTAINER);
+        FPRINTF (stderr, "              %s\n\n", MAINTAINER);
         exit (sig);
         break;
     default:
@@ -260,7 +260,7 @@ void
 warning (char string[], ...)
 {
     va_list args;
-    fprintf (stdout, "WARNING: ");
+    FPRINTF (stdout, "WARNING: ");
     va_start (args, string);
     vfprintf (stdout, string, args);
     va_end (args);
@@ -270,7 +270,7 @@ void
 usererror (char string[], ...)
 {
     va_list args;
-    fprintf (stdout, "\nERROR: ");
+    FPRINTF (stdout, "\nERROR: ");
     va_start (args, string);
     vfprintf (stdout, string, args);
     va_end (args);
@@ -280,7 +280,7 @@ usererror (char string[], ...)
 void
 sig_error (char string[], char filename[], long line)
 {
-    fprintf (stdout, "\nIn file %s on line %li\n%s\n", filename, line, string);
+    FPRINTF (stdout, "\nIn file %s on line %li\n%s\n", filename, line, string);
     exit (-11);
 }
 
@@ -314,27 +314,27 @@ malloc_error_found (int value)
     switch (value)
     {
     case 0:
-        fprintf (stderr, "vm_allocate failed\n");
+        FPRINTF (stderr, "vm_allocate failed\n");
         break;
     case 1:
-        fprintf (stderr, "vm_deallocate failed\n");
+        FPRINTF (stderr, "vm_deallocate failed\n");
         break;
     case 2:
-        fprintf (stderr, "vm_copy failed\n");
+        FPRINTF (stderr, "vm_copy failed\n");
         break;
     case 3:
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "I tried to reallocate or free space which was already freed\n");
         break;
     case 4:
-        fprintf (stderr, "Internal memory verification in heap failed\n");
+        FPRINTF (stderr, "Internal memory verification in heap failed\n");
         break;
     case 5:
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "I tried to reallocate or free space which was never allocated\n");
         break;
     default:
-        fprintf (stderr, "huh, what malloc error was this?\n");
+        FPRINTF (stderr, "huh, what malloc error was this?\n");
         break;
     }
     errno = ENOMEM;
@@ -357,7 +357,7 @@ LAMARC_malloc (const unsigned long size, const char file[], const long line)
     x = malloc (size);
     if (x == NULL)
     {
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "ERROR in memory allocation (malloc(%li)) in file %s on line %li\n",
                  size, file, line);
         exit (-1);
@@ -374,7 +374,7 @@ LAMARC_calloc (const unsigned long repeats, const unsigned long size,
     x = calloc (repeats, size);
     if (x == NULL)
     {
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "ERROR in memory allocation (calloc(%li,%li)) in file %s on line %li\n",
                  repeats, size, file, line);
         exit (-1);
@@ -390,7 +390,7 @@ LAMARC_realloc (void *ptr, const unsigned long size, const char file[],
     x = realloc (ptr, size);
     if (x == NULL)
     {
-        fprintf (stderr,
+        FPRINTF (stderr,
                  "ERROR in memory allocation (realloc(ptr,%li)) in file %s on lin %li\n",
                  size, file, line);
         exit (-1);
