@@ -19,7 +19,7 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-$Id: world.h,v 1.23 2002/06/20 06:25:40 beerli Exp $
+$Id: world.h,v 1.24 2002/08/12 21:13:59 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -33,7 +33,7 @@ extern void increase_timearchive (world_fmt * world, long locus, long sample,
 extern void calc_simple_param (world_fmt * world, data_fmt * data);
 extern void set_bounds (long *increment, long *steps, long *chains,
                             const option_fmt * options, const char type);
-extern void print_menu_locus (world_fmt * world, long locus);
+extern void print_menu_locus (FILE *file, world_fmt * world, long locus);
 extern void print_menu_chain (char type, long chain, long steps,
                                   world_fmt * world, option_fmt * options,
                                   long rep);
